Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/matomo-org/matomo.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorBeezyT <timo@ezdesign.de>2012-11-12 13:15:52 +0400
committerBeezyT <timo@ezdesign.de>2012-11-12 13:15:52 +0400
commit8c9ea809c403cdd80cf58aad5b885f2429933ee1 (patch)
tree56b7d46d91e19d35d30a033667334aa45466c841
parent600e1296da8742aadd00a3a5bacbca1cf5ba0779 (diff)
refs #2465
* Renaming Insight to Overlay * Includes a new minified piwik.js, generated as described in js/README. Please double-check whether the file is OK. * Servers that had the Insight plugin installed will need to delete it manually, right? git-svn-id: http://dev.piwik.org/svn/trunk@7445 59fd770c-687e-43c8-a1e3-f5a4ff64c105
-rw-r--r--config/global.ini.php12
-rw-r--r--core/ViewDataTable/HtmlTable.php6
-rw-r--r--js/piwik.js26
-rw-r--r--lang/en.php30
-rw-r--r--lang/ru.php12
-rw-r--r--piwik.js36
-rw-r--r--plugins/Actions/Controller.php4
-rw-r--r--plugins/CoreHome/templates/broadcast.js6
-rw-r--r--plugins/CoreHome/templates/datatable.js4
-rw-r--r--plugins/Overlay/API.php (renamed from plugins/Insight/API.php)0
-rw-r--r--plugins/Overlay/Controller.php (renamed from plugins/Insight/Controller.php)0
-rw-r--r--plugins/Overlay/Overlay.php (renamed from plugins/Insight/Insight.php)2
-rw-r--r--plugins/Overlay/client/client.css (renamed from plugins/Insight/client/insight.css)0
-rw-r--r--plugins/Overlay/client/client.js (renamed from plugins/Insight/client/client.js)0
-rw-r--r--plugins/Overlay/client/close.png (renamed from plugins/Insight/client/close.png)bin655 -> 655 bytes
-rw-r--r--plugins/Overlay/client/followingpages.js (renamed from plugins/Insight/client/followingpages.js)0
-rw-r--r--plugins/Overlay/client/linktags.eps (renamed from plugins/Insight/client/linktags.eps)0
-rw-r--r--plugins/Overlay/client/linktags.png (renamed from plugins/Insight/client/linktags.png)bin6489 -> 6489 bytes
-rw-r--r--plugins/Overlay/client/linktags.psd (renamed from plugins/Insight/client/linktags.psd)bin38518 -> 38518 bytes
-rw-r--r--plugins/Overlay/client/linktags_lessshadow.png (renamed from plugins/Insight/client/linktags_lessshadow.png)bin6353 -> 6353 bytes
-rw-r--r--plugins/Overlay/client/linktags_noshadow.png (renamed from plugins/Insight/client/linktags_noshadow.png)bin5355 -> 5355 bytes
-rw-r--r--plugins/Overlay/client/loading.gif (renamed from plugins/Insight/client/loading.gif)bin723 -> 723 bytes
-rw-r--r--plugins/Overlay/client/translations.js (renamed from plugins/Insight/client/translations.js)0
-rw-r--r--plugins/Overlay/client/urlnormalizer.js (renamed from plugins/Insight/client/urlnormalizer.js)0
-rw-r--r--plugins/Overlay/templates/index.css (renamed from plugins/Insight/templates/index.css)0
-rw-r--r--plugins/Overlay/templates/index.js (renamed from plugins/Insight/templates/insight.js)0
-rw-r--r--plugins/Overlay/templates/index.tpl (renamed from plugins/Insight/templates/index.tpl)0
-rw-r--r--plugins/Overlay/templates/index_noframe.tpl (renamed from plugins/Insight/templates/index_noframe.tpl)0
-rw-r--r--plugins/Overlay/templates/info.png (renamed from plugins/Insight/templates/info.png)bin778 -> 778 bytes
-rw-r--r--plugins/Overlay/templates/notify_parent_iframe.tpl (renamed from plugins/Insight/templates/notify_parent_iframe.tpl)0
-rw-r--r--plugins/Overlay/templates/sidebar.tpl (renamed from plugins/Insight/templates/sidebar.tpl)0
-rwxr-xr-xtests/PHPUnit/IntegrationTestCase.php2
32 files changed, 70 insertions, 70 deletions
diff --git a/lang/en.php b/lang/en.php
index a0c4f73761..e362577ab3 100644
--- a/lang/en.php
+++ b/lang/en.php
@@ -1806,19 +1806,19 @@ And thank you for using Piwik!',
'Transitions_NoDataForAction' => 'There\'s no data for %s',
'Transitions_NoDataForActionDetails' => 'Either the action had no pageviews during the period %s or it is invalid.',
'Transitions_ErrorBack' => 'Go back to the previous action',
- 'Insight_Insight' => 'Page Overlay',
- 'Insight_PluginDescription' => 'See analytics data as an overlay on your actual website.',
- 'Insight_Page' => 'Page',
- 'Insight_MainMetrics' => 'Main metrics',
- 'Insight_NoData' => 'There is no data for this page during the selected period.',
- 'Insight_OpenFullScreen' => 'Go full screen with sidebar',
- 'Insight_CloseFullScreen' => 'Close full screen',
- 'Insight_OneClick' => '1 click',
- 'Insight_Clicks' => '%s clicks',
- 'Insight_ClicksFromXLinks' => '%1$s clicks from one of %2$s links',
- 'Insight_Link' => 'Link',
- 'Insight_OpenNewTab' => 'Open Overlay in new tab',
- 'Insight_RedirectUrlError' => 'You are attempting to open Insight for the URL "%s". %s None of the URLs from the Piwik settings matches the link. Please add the domain there.',
- 'Insight_Domain' => 'Domain',
- 'Insight_NoFrameModeText' => 'The page overlay session will be launched in a new tab. %s If opening the tab doesn\'t work automatically, please %sclick here%s.'
+ 'Overlay_Overlay' => 'Page Overlay',
+ 'Overlay_PluginDescription' => 'See analytics data as an overlay on your actual website.',
+ 'Overlay_Page' => 'Page',
+ 'Overlay_MainMetrics' => 'Main metrics',
+ 'Overlay_NoData' => 'There is no data for this page during the selected period.',
+ 'Overlay_OpenFullScreen' => 'Go full screen with sidebar',
+ 'Overlay_CloseFullScreen' => 'Close full screen',
+ 'Overlay_OneClick' => '1 click',
+ 'Overlay_Clicks' => '%s clicks',
+ 'Overlay_ClicksFromXLinks' => '%1$s clicks from one of %2$s links',
+ 'Overlay_Link' => 'Link',
+ 'Overlay_OpenNewTab' => 'Open Overlay in new tab',
+ 'Overlay_RedirectUrlError' => 'You are attempting to open Page Overlay for the URL "%s". %s None of the URLs from the Piwik settings matches the link. Please add the domain there.',
+ 'Overlay_Domain' => 'Domain',
+ 'Overlay_NoFrameModeText' => 'The page overlay session will be launched in a new tab. %s If opening the tab doesn\'t work automatically, please %sclick here%s.'
);
diff --git a/lang/ru.php b/lang/ru.php
index 195d2cd94c..a09431cf2a 100644
--- a/lang/ru.php
+++ b/lang/ru.php
@@ -1786,10 +1786,10 @@ $translations = array(
'Transitions_NoDataForAction' => 'Нет данныз для %s',
'Transitions_NoDataForActionDetails' => 'Не было совершено таких действий %s или они неправильны.',
'Transitions_ErrorBack' => 'Верниться к предыдущему действию',
- 'Insight_Insight' => 'Глубина проникновения',
- 'Insight_Page' => 'Страница',
- 'Insight_MainMetrics' => 'Основные показатели',
- 'Insight_NoData' => 'Нет данных по этой странице за выбранный период.',
- 'Insight_OpenFullScreen' => 'Перейти к полному экрану',
- 'Insight_CloseFullScreen' => 'Закрыть полный экран',
+ 'Overlay_Overlay' => 'Глубина проникновения',
+ 'Overlay_Page' => 'Страница',
+ 'Overlay_MainMetrics' => 'Основные показатели',
+ 'Overlay_NoData' => 'Нет данных по этой странице за выбранный период.',
+ 'Overlay_OpenFullScreen' => 'Перейти к полному экрану',
+ 'Overlay_CloseFullScreen' => 'Закрыть полный экран',
);
diff --git a/piwik.js b/piwik.js
index d8d976112c..7283541fd9 100644
--- a/piwik.js
+++ b/piwik.js
@@ -10,21 +10,21 @@
if(!this.JSON2){this.JSON2={}}(function(){function d(f){return f<10?"0"+f:f}function l(n,m){var f=Object.prototype.toString.apply(n);if(f==="[object Date]"){return isFinite(n.valueOf())?n.getUTCFullYear()+"-"+d(n.getUTCMonth()+1)+"-"+d(n.getUTCDate())+"T"+d(n.getUTCHours())+":"+d(n.getUTCMinutes())+":"+d(n.getUTCSeconds())+"Z":null}if(f==="[object String]"||f==="[object Number]"||f==="[object Boolean]"){return n.valueOf()}if(f!=="[object Array]"&&typeof n.toJSON==="function"){return n.toJSON(m)}return n}var c=new RegExp("[\u0000\u00ad\u0600-\u0604\u070f\u17b4\u17b5\u200c-\u200f\u2028-\u202f\u2060-\u206f\ufeff\ufff0-\uffff]","g"),e='\\\\\\"\x00-\x1f\x7f-\x9f\u00ad\u0600-\u0604\u070f\u17b4\u17b5\u200c-\u200f\u2028-\u202f\u2060-\u206f\ufeff\ufff0-\uffff]',i=new RegExp("["+e,"g"),j,b,k={"\b":"\\b","\t":"\\t","\n":"\\n","\f":"\\f","\r":"\\r",'"':'\\"',"\\":"\\\\"},h;
function a(f){i.lastIndex=0;return i.test(f)?'"'+f.replace(i,function(m){var n=k[m];return typeof n==="string"?n:"\\u"+("0000"+m.charCodeAt(0).toString(16)).slice(-4)})+'"':'"'+f+'"'}function g(s,p){var n,m,t,f,q=j,o,r=p[s];if(r&&typeof r==="object"){r=l(r,s)}if(typeof h==="function"){r=h.call(p,s,r)}switch(typeof r){case"string":return a(r);case"number":return isFinite(r)?String(r):"null";case"boolean":case"null":return String(r);case"object":if(!r){return"null"}j+=b;o=[];if(Object.prototype.toString.apply(r)==="[object Array]"){f=r.length;for(n=0;n<f;n+=1){o[n]=g(n,r)||"null"}t=o.length===0?"[]":j?"[\n"+j+o.join(",\n"+j)+"\n"+q+"]":"["+o.join(",")+"]";j=q;return t}if(h&&typeof h==="object"){f=h.length;for(n=0;n<f;n+=1){if(typeof h[n]==="string"){m=h[n];t=g(m,r);if(t){o.push(a(m)+(j?": ":":")+t)}}}}else{for(m in r){if(Object.prototype.hasOwnProperty.call(r,m)){t=g(m,r);if(t){o.push(a(m)+(j?": ":":")+t)}}}}t=o.length===0?"{}":j?"{\n"+j+o.join(",\n"+j)+"\n"+q+"}":"{"+o.join(",")+"}";j=q;
return t}}if(typeof JSON2.stringify!=="function"){JSON2.stringify=function(o,m,n){var f;j="";b="";if(typeof n==="number"){for(f=0;f<n;f+=1){b+=" "}}else{if(typeof n==="string"){b=n}}h=m;if(m&&typeof m!=="function"&&(typeof m!=="object"||typeof m.length!=="number")){throw new Error("JSON.stringify")}return g("",{"":o})}}if(typeof JSON2.parse!=="function"){JSON2.parse=function(o,f){var n;function m(s,r){var q,p,t=s[r];if(t&&typeof t==="object"){for(q in t){if(Object.prototype.hasOwnProperty.call(t,q)){p=m(t,q);if(p!==undefined){t[q]=p}else{delete t[q]}}}}return f.call(s,r,t)}o=String(o);c.lastIndex=0;if(c.test(o)){o=o.replace(c,function(p){return"\\u"+("0000"+p.charCodeAt(0).toString(16)).slice(-4)})}if((new RegExp("^[\\],:{}\\s]*$")).test(o.replace(new RegExp('\\\\(?:["\\\\/bfnrt]|u[0-9a-fA-F]{4})',"g"),"@").replace(new RegExp('"[^"\\\\\n\r]*"|true|false|null|-?\\d+(?:\\.\\d*)?(?:[eE][+\\-]?\\d+)?',"g"),"]").replace(new RegExp("(?:^|:|,)(?:\\s*\\[)+","g"),""))){n=eval("("+o+")");
-return typeof f==="function"?m({"":n},""):n}throw new SyntaxError("JSON.parse")}}}());var _paq=_paq||[],Piwik=Piwik||(function(){var f,a={},o=document,d=navigator,A=screen,w=window,l=false,u=[],h=w.encodeURIComponent,v=w.decodeURIComponent,e=unescape,B,D;function q(i){return"undefined"!==typeof i}function m(i){return typeof i==="function"}function z(i){return typeof i==="object"}function j(i){return typeof i==="string"||i instanceof String}function G(){var L,N,M;for(L=0;L<arguments.length;L+=1){M=arguments[L];N=M.shift();if(j(N)){B[N].apply(B,M)}else{N.apply(B,M)}}}function J(N,M,L,i){if(N.addEventListener){N.addEventListener(M,L,i);return true}if(N.attachEvent){return N.attachEvent("on"+M,L)}N["on"+M]=L}function E(M,P){var L="",O,N;for(O in a){if(Object.prototype.hasOwnProperty.call(a,O)){N=a[O][M];if(m(N)){L+=N(P)}}}return L}function H(){var i;E("unload");if(f){do{i=new Date()}while(i.getTimeAlias()<f)}}function F(){var L;if(!l){l=true;E("load");for(L=0;L<u.length;L++){u[L]()}}return true
-}function k(){var L;if(o.addEventListener){J(o,"DOMContentLoaded",function i(){o.removeEventListener("DOMContentLoaded",i,false);F()})}else{if(o.attachEvent){o.attachEvent("onreadystatechange",function i(){if(o.readyState==="complete"){o.detachEvent("onreadystatechange",i);F()}});if(o.documentElement.doScroll&&w===w.top){(function i(){if(!l){try{o.documentElement.doScroll("left")}catch(M){setTimeout(i,0);return}F()}}())}}}if((new RegExp("WebKit")).test(d.userAgent)){L=setInterval(function(){if(l||/loaded|complete/.test(o.readyState)){clearInterval(L);F()}},10)}J(w,"load",F,false)}function r(){var i="";try{i=w.top.document.referrer}catch(M){if(w.parent){try{i=w.parent.document.referrer}catch(L){i=""}}}if(i===""){i=o.referrer}return i}function g(i){var M=new RegExp("^([a-z]+):"),L=M.exec(i);return L?L[1]:null}function c(i){var M=new RegExp("^(?:(?:https?|ftp):)/*(?:[^@]+@)?([^:/#]+)"),L=M.exec(i);return L?L[1]:i}function y(M,L){var P=new RegExp("^(?:https?|ftp)(?::/*(?:[^?]+)[?])([^#]+)"),O=P.exec(M),N=new RegExp("(?:^|&)"+L+"=([^&]*)"),i=O?N.exec(O[1]):0;
-return i?v(i[1]):""}function n(i){return e(h(i))}function I(ab){var N=function(W,i){return(W<<i)|(W>>>(32-i))},ac=function(ai){var ah="",ag,W;for(ag=7;ag>=0;ag--){W=(ai>>>(ag*4))&15;ah+=W.toString(16)}return ah},Q,ae,ad,M=[],U=1732584193,S=4023233417,R=2562383102,P=271733878,O=3285377520,aa,Z,Y,X,V,af,L,T=[];ab=n(ab);L=ab.length;for(ae=0;ae<L-3;ae+=4){ad=ab.charCodeAt(ae)<<24|ab.charCodeAt(ae+1)<<16|ab.charCodeAt(ae+2)<<8|ab.charCodeAt(ae+3);T.push(ad)}switch(L&3){case 0:ae=2147483648;break;case 1:ae=ab.charCodeAt(L-1)<<24|8388608;break;case 2:ae=ab.charCodeAt(L-2)<<24|ab.charCodeAt(L-1)<<16|32768;break;case 3:ae=ab.charCodeAt(L-3)<<24|ab.charCodeAt(L-2)<<16|ab.charCodeAt(L-1)<<8|128;break}T.push(ae);while((T.length&15)!==14){T.push(0)}T.push(L>>>29);T.push((L<<3)&4294967295);for(Q=0;Q<T.length;Q+=16){for(ae=0;ae<16;ae++){M[ae]=T[Q+ae]}for(ae=16;ae<=79;ae++){M[ae]=N(M[ae-3]^M[ae-8]^M[ae-14]^M[ae-16],1)}aa=U;Z=S;Y=R;X=P;V=O;for(ae=0;ae<=19;ae++){af=(N(aa,5)+((Z&Y)|(~Z&X))+V+M[ae]+1518500249)&4294967295;
-V=X;X=Y;Y=N(Z,30);Z=aa;aa=af}for(ae=20;ae<=39;ae++){af=(N(aa,5)+(Z^Y^X)+V+M[ae]+1859775393)&4294967295;V=X;X=Y;Y=N(Z,30);Z=aa;aa=af}for(ae=40;ae<=59;ae++){af=(N(aa,5)+((Z&Y)|(Z&X)|(Y&X))+V+M[ae]+2400959708)&4294967295;V=X;X=Y;Y=N(Z,30);Z=aa;aa=af}for(ae=60;ae<=79;ae++){af=(N(aa,5)+(Z^Y^X)+V+M[ae]+3395469782)&4294967295;V=X;X=Y;Y=N(Z,30);Z=aa;aa=af}U=(U+aa)&4294967295;S=(S+Z)&4294967295;R=(R+Y)&4294967295;P=(P+X)&4294967295;O=(O+V)&4294967295}af=ac(U)+ac(S)+ac(R)+ac(P)+ac(O);return af.toLowerCase()}function C(M,i,L){if(M==="translate.googleusercontent.com"){if(L===""){L=i}i=y(i,"u");M=c(i)}else{if(M==="cc.bingj.com"||M==="webcache.googleusercontent.com"||M.slice(0,5)==="74.6."){i=o.links[0].href;M=c(i)}}return[M,i,L]}function s(L){var i=L.length;if(L.charAt(--i)==="."){L=L.slice(0,i)}if(L.slice(0,2)==="*."){L=L.slice(1)}return L}function K(L){if(!j(L)){L=L.text||"";var i=o.getElementsByTagName("title");if(i&&q(i[0])){L=i[0].text}}return L}function x(O,S){var U="Piwik_Insight";var R=o.referrer;
-var i=O;i=i.substring(0,i.length-9);i.substring(i.substring(0,7)==="http://"?7:8,i.length);R.substring(R.substring(0,7)==="http://"?7:8,R.length);if(R.substring(0,i.length)===i){var M=new RegExp("^"+i+"index\\.php\\?module=Insight&action=startInsightSession&idsite=([0-9]+)&period=([^&]+)&date=([^&]+)$");var N=R.match(M);if(N){var P=N[1];if(parseInt(P,10)!==S){return false}var Q=N[2];var L=N[3];window.name=U+"###"+Q+"###"+L}}var T=w.name.split("###");return T.length===3&&T[0]===U}function b(M,S){var T=window.name.split("###");var R=M.substring(0,M.length-9);var N=T[1];var i=T[2];var L=false;var O=function(){if(!L){L=true;Piwik_Insight_Client.initialize(R,S,N,i)}};var Q=document.createElement("script");Q.type="text/javascript";Q.onreadystatechange=function(){if(this.readyState==="loaded"||this.readyState==="complete"){O()}};Q.onload=O;Q.src=R+"plugins/Insight/client/client.js";var P=document.getElementsByTagName("head")[0];P.appendChild(Q)}function t(af,aE){var O=C(o.domain,w.location.href,r()),aX=s(O[0]),bb=O[1],aK=O[2],aI="GET",N=af||"",a1=aE||"",av,al=o.title,an="7z|aac|ar[cj]|as[fx]|avi|bin|csv|deb|dmg|doc|exe|flv|gif|gz|gzip|hqx|jar|jpe?g|js|mp(2|3|4|e?g)|mov(ie)?|ms[ip]|od[bfgpst]|og[gv]|pdf|phps|png|ppt|qtm?|ra[mr]?|rpm|sea|sit|tar|t?bz2?|tgz|torrent|txt|wav|wm[av]|wpd||xls|xml|z|zip",aG=[aX],R=[],az=[],ae=[],aF=500,S,ag,T,U,ap=["pk_campaign","piwik_campaign","utm_campaign","utm_source","utm_medium"],ak=["pk_kwd","piwik_kwd","utm_term"],a9="_pk_",X,ba,V=false,a4,ar,au,ac=63072000000,ad=1800000,aw=15768000000,aa=o.location.protocol==="https",Q=false,aA={},a5=200,aQ={},a2={},aN=false,aL=false,aJ,aB,Y,ao=I,aM,at;
-function aS(bk,bh,bg,bj,bf,bi){if(V){return}var be;if(bg){be=new Date();be.setTime(be.getTime()+bg)}o.cookie=bk+"="+h(bh)+(bg?";expires="+be.toGMTString():"")+";path="+(bj||"/")+(bf?";domain="+bf:"")+(bi?";secure":"")}function ab(bg){if(V){return 0}var be=new RegExp("(^|;)[ ]*"+bg+"=([^;]*)"),bf=be.exec(o.cookie);return bf?v(bf[2]):0}function a6(be){var bf;if(T){bf=new RegExp("#.*");return be.replace(bf,"")}return be}function aW(bg,be){var bh=g(be),bf;if(bh){return be}if(be.slice(0,1)==="/"){return g(bg)+"://"+c(bg)+be}bg=a6(bg);if((bf=bg.indexOf("?"))>=0){bg=bg.slice(0,bf)}if((bf=bg.lastIndexOf("/"))!==bg.length-1){bg=bg.slice(0,bf+1)}return bg+be}function aH(bh){var bf,be,bg;for(bf=0;bf<aG.length;bf++){be=s(aG[bf].toLowerCase());if(bh===be){return true}if(be.slice(0,1)==="."){if(bh===be.slice(1)){return true}bg=bh.length-be.length;if((bg>0)&&(bh.slice(bg)===be)){return true}}}return false}function bd(be){var bf=new Image(1,1);bf.onload=function(){};bf.src=N+(N.indexOf("?")<0?"?":"&")+be
-}function aT(be){try{var bg=w.XMLHttpRequest?new w.XMLHttpRequest():w.ActiveXObject?new ActiveXObject("Microsoft.XMLHTTP"):null;bg.open("POST",N,true);bg.onreadystatechange=function(){if(this.readyState===4&&this.status!==200){bd(be)}};bg.setRequestHeader("Content-Type","application/x-www-form-urlencoded; charset=UTF-8");bg.send(be)}catch(bf){bd(be)}}function aq(bg,bf){var be=new Date();if(!a4){if(aI==="POST"){aT(bg)}else{bd(bg)}f=be.getTime()+bf}}function aR(be){return a9+be+"."+a1+"."+aM}function P(){if(V){return"0"}if(!q(d.cookieEnabled)){var be=aR("testcookie");aS(be,"1");return ab(be)==="1"?"1":"0"}return d.cookieEnabled?"1":"0"}function aC(){aM=ao((X||aX)+(ba||"/")).slice(0,4)}function Z(){var bf=aR("cvar"),be=ab(bf);if(be.length){be=JSON2.parse(be);if(z(be)){return be}}return{}}function M(){if(Q===false){Q=Z()}}function a0(){var be=new Date();aJ=be.getTime()}function W(bi,bf,be,bh,bg,bj){aS(aR("id"),bi+"."+bf+"."+be+"."+bh+"."+bg+"."+bj,ac,ba,X,aa)}function L(){var bf=new Date(),be=Math.round(bf.getTime()/1000),bh=ab(aR("id")),bg;
-if(bh){bg=bh.split(".");bg.unshift("0")}else{if(!at){at=ao((d.userAgent||"")+(d.platform||"")+JSON2.stringify(a2)+be).slice(0,16)}bg=["1",at,be,0,be,"",""]}return bg}function i(){var be=ab(aR("ref"));if(be.length){try{be=JSON2.parse(be);if(z(be)){return be}}catch(bf){}}return["","",0,""]}function am(bg,bF,bG,bi){var bD,bf=new Date(),bo=Math.round(bf.getTime()/1000),bI,bE,bk,bw,bA,bn,by,bl,bC,bj=1024,bJ,br,bz=Q,bu=aR("id"),bp=aR("ses"),bq=aR("ref"),bK=aR("cvar"),bx=L(),bt=ab(bp),bB=i(),bH=av||bb,bm,be;if(V){V=false;aS(bu,"",-86400,ba,X);aS(bp,"",-86400,ba,X);aS(bK,"",-86400,ba,X);aS(bq,"",-86400,ba,X);V=true}if(a4){return""}bI=bx[0];bE=bx[1];bw=bx[2];bk=bx[3];bA=bx[4];bn=bx[5];if(!q(bx[6])){bx[6]=""}by=bx[6];if(!q(bi)){bi=""}var bs=document.characterSet||document.charset;if(!bs||bs.toLowerCase()==="utf-8"||bs.toLowerCase()==="iso-8859-1"||bs.toLowerCase()==="iso-8859-15"){bs=null}bm=bB[0];be=bB[1];bl=bB[2];bC=bB[3];if(!bt){bk++;bn=bA;if(!au||!bm.length){for(bD in ap){if(Object.prototype.hasOwnProperty.call(ap,bD)){bm=y(bH,ap[bD]);
-if(bm.length){break}}}for(bD in ak){if(Object.prototype.hasOwnProperty.call(ak,bD)){be=y(bH,ak[bD]);if(be.length){break}}}}bJ=c(aK);br=bC.length?c(bC):"";if(bJ.length&&!aH(bJ)&&(!au||!br.length||aH(br))){bC=aK}if(bC.length||bm.length){bl=bo;bB=[bm,be,bl,a6(bC.slice(0,bj))];aS(bq,JSON2.stringify(bB),aw,ba,X,aa)}}bg+="&idsite="+a1+"&rec=1&r="+String(Math.random()).slice(2,8)+"&h="+bf.getHours()+"&m="+bf.getMinutes()+"&s="+bf.getSeconds()+"&url="+h(a6(bH))+(aK.length?"&urlref="+h(a6(aK)):"")+"&_id="+bE+"&_idts="+bw+"&_idvc="+bk+"&_idn="+bI+(bm.length?"&_rcn="+h(bm):"")+(be.length?"&_rck="+h(be):"")+"&_refts="+bl+"&_viewts="+bn+(String(by).length?"&_ects="+by:"")+(String(bC).length?"&_ref="+h(a6(bC.slice(0,bj))):"")+(bs?"&cs="+h(bs):"");var bh=JSON2.stringify(aA);if(bh.length>2){bg+="&cvar="+h(bh)}for(bD in a2){if(Object.prototype.hasOwnProperty.call(a2,bD)){bg+="&"+bD+"="+a2[bD]}}if(bF){bg+="&data="+h(JSON2.stringify(bF))}else{if(U){bg+="&data="+h(JSON2.stringify(U))}}if(Q){var bv=JSON2.stringify(Q);
-if(bv.length>2){bg+="&_cvar="+h(bv)}for(bD in bz){if(Object.prototype.hasOwnProperty.call(bz,bD)){if(Q[bD][0]===""||Q[bD][1]===""){delete Q[bD]}}}aS(bK,JSON2.stringify(Q),ad,ba,X,aa)}W(bE,bw,bk,bo,bn,q(bi)&&String(bi).length?bi:by);aS(bp,"*",ad,ba,X,aa);bg+=E(bG);return bg}function aV(bh,bg,bl,bi,be,bo){var bj="idgoal=0",bk,bf=new Date(),bm=[],bn;if(String(bh).length){bj+="&ec_id="+h(bh);bk=Math.round(bf.getTime()/1000)}bj+="&revenue="+bg;if(String(bl).length){bj+="&ec_st="+bl}if(String(bi).length){bj+="&ec_tx="+bi}if(String(be).length){bj+="&ec_sh="+be}if(String(bo).length){bj+="&ec_dt="+bo}if(aQ){for(bn in aQ){if(Object.prototype.hasOwnProperty.call(aQ,bn)){if(!q(aQ[bn][1])){aQ[bn][1]=""}if(!q(aQ[bn][2])){aQ[bn][2]=""}if(!q(aQ[bn][3])||String(aQ[bn][3]).length===0){aQ[bn][3]=0}if(!q(aQ[bn][4])||String(aQ[bn][4]).length===0){aQ[bn][4]=1}bm.push(aQ[bn])}}bj+="&ec_items="+h(JSON2.stringify(bm))}bj=am(bj,U,"ecommerce",bk);aq(bj,aF)}function aU(be,bi,bh,bg,bf,bj){if(String(be).length&&q(bi)){aV(be,bi,bh,bg,bf,bj)
-}}function a8(be){if(q(be)){aV("",be,"","","","")}}function ay(bh,bi){var be=new Date(),bg=am("action_name="+h(K(bh||al)),bi,"log");aq(bg,aF);if(S&&ag&&!aL){aL=true;J(o,"click",a0);J(o,"mouseup",a0);J(o,"mousedown",a0);J(o,"mousemove",a0);J(o,"mousewheel",a0);J(w,"DOMMouseScroll",a0);J(w,"scroll",a0);J(o,"keypress",a0);J(o,"keydown",a0);J(o,"keyup",a0);J(w,"resize",a0);J(w,"focus",a0);J(w,"blur",a0);aJ=be.getTime();setTimeout(function bf(){var bj=new Date(),bk;if((aJ+ag)>bj.getTime()){if(S<bj.getTime()){bk=am("ping=1",bi,"ping");aq(bk,aF)}setTimeout(bf,ag)}},ag)}}function aj(be,bh,bf,bi){var bg=am("search="+h(be)+(bh?"&search_cat="+h(bh):"")+(q(bf)?"&search_count="+bf:""),bi,"sitesearch");aq(bg,aF)}function aD(be,bh,bg){var bf=am("idgoal="+be+(bh?"&revenue="+bh:""),bg,"goal");aq(bf,aF)}function aZ(bf,be,bh){var bg=am(be+"="+h(a6(bf)),bh,"link");aq(bg,aF)}function a3(bf,be){if(bf!==""){return bf+be.charAt(0).toUpperCase()+be.slice(1)}return be}function ai(bj){var bi,be,bh=["","webkit","ms","moz"],bg;
-if(!ar){for(be=0;be<bh.length;be++){bg=bh[be];if(Object.prototype.hasOwnProperty.call(o,a3(bg,"hidden"))){if(o[a3(bg,"visibilityState")]==="prerender"){bi=true}break}}}if(bi){J(o,bg+"visibilitychange",function bf(){o.removeEventListener(bg+"visibilitychange",bf,false);bj()});return}bj()}function ah(bg,bf){var bh,be="(^| )(piwik[_-]"+bf;if(bg){for(bh=0;bh<bg.length;bh++){be+="|"+bg[bh]}}be+=")( |$)";return new RegExp(be)}function aY(bh,be,bi){var bg=ah(az,"download"),bf=ah(ae,"link"),bj=new RegExp("\\.("+an+")([?&#]|$)","i");return bf.test(bh)?"link":(bg.test(bh)||bj.test(be)?"download":(bi?0:"link"))}function aP(bj){var bh,bf,be;while((bh=bj.parentNode)!==null&&q(bh)&&((bf=bj.tagName.toUpperCase())!=="A"&&bf!=="AREA")){bj=bh}if(q(bj.href)){var bk=bj.hostname||c(bj.href),bl=bk.toLowerCase(),bg=bj.href.replace(bk,bl),bi=new RegExp("^(javascript|vbscript|jscript|mocha|livescript|ecmascript|mailto):","i");if(!bi.test(bg)){be=aY(bj.className,bg,aH(bl));if(be){bg=e(bg);aZ(bg,be)}}}}function bc(be){var bf,bg;
-be=be||w.event;bf=be.which||be.button;bg=be.target||be.srcElement;if(be.type==="click"){if(bg){aP(bg)}}else{if(be.type==="mousedown"){if((bf===1||bf===2)&&bg){aB=bf;Y=bg}else{aB=Y=null}}else{if(be.type==="mouseup"){if(bf===aB&&bg===Y){aP(bg)}aB=Y=null}}}}function aO(bf,be){if(be){J(bf,"mouseup",bc,false);J(bf,"mousedown",bc,false)}else{J(bf,"click",bc,false)}}function ax(bf){if(!aN){aN=true;var bg,be=ah(R,"ignore"),bh=o.links;if(bh){for(bg=0;bg<bh.length;bg++){if(!be.test(bh[bg].className)){aO(bh[bg],bf)}}}}}function a7(){var bf,bg,bh={pdf:"application/pdf",qt:"video/quicktime",realp:"audio/x-pn-realaudio-plugin",wma:"application/x-mplayer2",dir:"application/x-director",fla:"application/x-shockwave-flash",java:"application/x-java-vm",gears:"application/x-googlegears",ag:"application/x-silverlight"},be=(new RegExp("Mac OS X.*Safari/")).test(d.userAgent)?w.devicePixelRatio||1:1;if(!((new RegExp("MSIE")).test(d.userAgent))){if(d.mimeTypes&&d.mimeTypes.length){for(bf in bh){if(Object.prototype.hasOwnProperty.call(bh,bf)){bg=d.mimeTypes[bh[bf]];
-a2[bf]=(bg&&bg.enabledPlugin)?"1":"0"}}}if(typeof navigator.javaEnabled!=="unknown"&&q(d.javaEnabled)&&d.javaEnabled()){a2.java="1"}if(m(w.GearsFactory)){a2.gears="1"}a2.cookie=P()}a2.res=A.width*be+"x"+A.height*be}a7();aC();return{getVisitorId:function(){return(L())[1]},getVisitorInfo:function(){return L()},getAttributionInfo:function(){return i()},getAttributionCampaignName:function(){return i()[0]},getAttributionCampaignKeyword:function(){return i()[1]},getAttributionReferrerTimestamp:function(){return i()[2]},getAttributionReferrerUrl:function(){return i()[3]},setTrackerUrl:function(be){N=be},setSiteId:function(be){a1=be},setCustomData:function(be,bf){if(z(be)){U=be}else{if(!U){U=[]}U[be]=bf}},getCustomData:function(){return U},setCustomVariable:function(bf,be,bi,bg){var bh;if(!q(bg)){bg="visit"}if(bf>0){be=q(be)&&!j(be)?String(be):be;bi=q(bi)&&!j(bi)?String(bi):bi;bh=[be.slice(0,a5),bi.slice(0,a5)];if(bg==="visit"||bg===2){M();Q[bf]=bh}else{if(bg==="page"||bg===3){aA[bf]=bh}}}},getCustomVariable:function(bf,bg){var be;
-if(!q(bg)){bg="visit"}if(bg==="page"||bg===3){be=aA[bf]}else{if(bg==="visit"||bg===2){M();be=Q[bf]}}if(!q(be)||(be&&be[0]==="")){return false}return be},deleteCustomVariable:function(be,bf){if(this.getCustomVariable(be,bf)){this.setCustomVariable(be,"","",bf)}},setLinkTrackingTimer:function(be){aF=be},setDownloadExtensions:function(be){an=be},addDownloadExtensions:function(be){an+="|"+be},setDomains:function(be){aG=j(be)?[be]:be;aG.push(aX)},setIgnoreClasses:function(be){R=j(be)?[be]:be},setRequestMethod:function(be){aI=be||"GET"},setReferrerUrl:function(be){aK=be},setCustomUrl:function(be){av=aW(bb,be)},setDocumentTitle:function(be){al=be},setDownloadClasses:function(be){az=j(be)?[be]:be},setLinkClasses:function(be){ae=j(be)?[be]:be},setCampaignNameKey:function(be){ap=j(be)?[be]:be},setCampaignKeywordKey:function(be){ak=j(be)?[be]:be},discardHashTag:function(be){T=be},setCookieNamePrefix:function(be){a9=be;Q=Z()},setCookieDomain:function(be){X=s(be);aC()},setCookiePath:function(be){ba=be;
-aC()},setVisitorCookieTimeout:function(be){ac=be*1000},setSessionCookieTimeout:function(be){ad=be*1000},setReferralCookieTimeout:function(be){aw=be*1000},setConversionAttributionFirstReferrer:function(be){au=be},disableCookies:function(){V=true;a2.cookie="0"},setDoNotTrack:function(bf){var be=d.doNotTrack||d.msDoNotTrack;a4=bf&&(be==="yes"||be==="1");if(a4){this.disableCookies()}},addListener:function(bf,be){aO(bf,be)},enableLinkTracking:function(be){if(l){ax(be)}else{u.push(function(){ax(be)})}},setHeartBeatTimer:function(bg,bf){var be=new Date();S=be.getTime()+bg*1000;ag=bf*1000},killFrame:function(){if(w.location!==w.top.location){w.top.location=w.location}},redirectFile:function(be){if(w.location.protocol==="file:"){w.location=be}},setCountPreRendered:function(be){ar=be},trackGoal:function(be,bg,bf){ai(function(){aD(be,bg,bf)})},trackLink:function(bf,be,bg){ai(function(){aZ(bf,be,bg)})},trackPageView:function(be,bf){if(x(N,a1)){ai(function(){b(N,a1)})}else{ai(function(){ay(be,bf)})}},trackSiteSearch:function(be,bg,bf){ai(function(){aj(be,bg,bf)
-})},setEcommerceView:function(bh,be,bg,bf){if(!q(bg)||!bg.length){bg=""}else{if(bg instanceof Array){bg=JSON2.stringify(bg)}}aA[5]=["_pkc",bg];if(q(bf)&&String(bf).length){aA[2]=["_pkp",bf]}if((!q(bh)||!bh.length)&&(!q(be)||!be.length)){return}if(q(bh)&&bh.length){aA[3]=["_pks",bh]}if(!q(be)||!be.length){be=""}aA[4]=["_pkn",be]},addEcommerceItem:function(bi,be,bg,bf,bh){if(bi.length){aQ[bi]=[bi,be,bg,bf,bh]}},trackEcommerceOrder:function(be,bi,bh,bg,bf,bj){aU(be,bi,bh,bg,bf,bj)},trackEcommerceCartUpdate:function(be){a8(be)}}}function p(){return{push:G}}J(w,"beforeunload",H,false);k();Date.prototype.getTimeAlias=Date.prototype.getTime;B=new t();for(D=0;D<_paq.length;D++){G(_paq[D])}_paq=new p();return{addPlugin:function(i,L){a[i]=L},getTracker:function(i,L){return new t(i,L)},getAsyncTracker:function(){return B}}}()),piwik_track,piwik_log=function(b,f,d,g){function a(h){try{return eval("piwik_"+h)}catch(i){}return}var c,e=Piwik.getTracker(d,f);e.setDocumentTitle(b);e.setCustomData(g);
-c=a("tracker_pause");if(c){e.setLinkTrackingTimer(c)}c=a("download_extensions");if(c){e.setDownloadExtensions(c)}c=a("hosts_alias");if(c){e.setDomains(c)}c=a("ignore_classes");if(c){e.setIgnoreClasses(c)}e.trackPageView();if(a("install_tracker")){piwik_track=function(i,k,j,h){e.setSiteId(k);e.setTrackerUrl(j);e.trackLink(i,h)};e.enableLinkTracking()}}; \ No newline at end of file
+return typeof f==="function"?m({"":n},""):n}throw new SyntaxError("JSON.parse")}}}());var _paq=_paq||[],Piwik=Piwik||(function(){var e,a={},n=document,c=navigator,z=screen,w=window,k=false,u=[],g=w.encodeURIComponent,v=w.decodeURIComponent,d=unescape,A,D;function p(i){return"undefined"!==typeof i}function l(i){return typeof i==="function"}function y(i){return typeof i==="object"}function h(i){return typeof i==="string"||i instanceof String}function G(){var L,N,M;for(L=0;L<arguments.length;L+=1){M=arguments[L];N=M.shift();if(h(N)){A[N].apply(A,M)}else{N.apply(A,M)}}}function J(N,M,L,i){if(N.addEventListener){N.addEventListener(M,L,i);return true}if(N.attachEvent){return N.attachEvent("on"+M,L)}N["on"+M]=L}function E(M,P){var L="",O,N;for(O in a){if(Object.prototype.hasOwnProperty.call(a,O)){N=a[O][M];if(l(N)){L+=N(P)}}}return L}function H(){var i;E("unload");if(e){do{i=new Date()}while(i.getTimeAlias()<e)}}function F(){var L;if(!k){k=true;E("load");for(L=0;L<u.length;L++){u[L]()}}return true
+}function j(){var L;if(n.addEventListener){J(n,"DOMContentLoaded",function i(){n.removeEventListener("DOMContentLoaded",i,false);F()})}else{if(n.attachEvent){n.attachEvent("onreadystatechange",function i(){if(n.readyState==="complete"){n.detachEvent("onreadystatechange",i);F()}});if(n.documentElement.doScroll&&w===w.top){(function i(){if(!k){try{n.documentElement.doScroll("left")}catch(M){setTimeout(i,0);return}F()}}())}}}if((new RegExp("WebKit")).test(c.userAgent)){L=setInterval(function(){if(k||/loaded|complete/.test(n.readyState)){clearInterval(L);F()}},10)}J(w,"load",F,false)}function q(){var i="";try{i=w.top.document.referrer}catch(M){if(w.parent){try{i=w.parent.document.referrer}catch(L){i=""}}}if(i===""){i=n.referrer}return i}function f(i){var M=new RegExp("^([a-z]+):"),L=M.exec(i);return L?L[1]:null}function b(i){var M=new RegExp("^(?:(?:https?|ftp):)/*(?:[^@]+@)?([^:/#]+)"),L=M.exec(i);return L?L[1]:i}function x(M,L){var P=new RegExp("^(?:https?|ftp)(?::/*(?:[^?]+)[?])([^#]+)"),O=P.exec(M),N=new RegExp("(?:^|&)"+L+"=([^&]*)"),i=O?N.exec(O[1]):0;
+return i?v(i[1]):""}function m(i){return d(g(i))}function I(ab){var N=function(W,i){return(W<<i)|(W>>>(32-i))},ac=function(ai){var ah="",ag,W;for(ag=7;ag>=0;ag--){W=(ai>>>(ag*4))&15;ah+=W.toString(16)}return ah},Q,ae,ad,M=[],U=1732584193,S=4023233417,R=2562383102,P=271733878,O=3285377520,aa,Z,Y,X,V,af,L,T=[];ab=m(ab);L=ab.length;for(ae=0;ae<L-3;ae+=4){ad=ab.charCodeAt(ae)<<24|ab.charCodeAt(ae+1)<<16|ab.charCodeAt(ae+2)<<8|ab.charCodeAt(ae+3);T.push(ad)}switch(L&3){case 0:ae=2147483648;break;case 1:ae=ab.charCodeAt(L-1)<<24|8388608;break;case 2:ae=ab.charCodeAt(L-2)<<24|ab.charCodeAt(L-1)<<16|32768;break;case 3:ae=ab.charCodeAt(L-3)<<24|ab.charCodeAt(L-2)<<16|ab.charCodeAt(L-1)<<8|128;break}T.push(ae);while((T.length&15)!==14){T.push(0)}T.push(L>>>29);T.push((L<<3)&4294967295);for(Q=0;Q<T.length;Q+=16){for(ae=0;ae<16;ae++){M[ae]=T[Q+ae]}for(ae=16;ae<=79;ae++){M[ae]=N(M[ae-3]^M[ae-8]^M[ae-14]^M[ae-16],1)}aa=U;Z=S;Y=R;X=P;V=O;for(ae=0;ae<=19;ae++){af=(N(aa,5)+((Z&Y)|(~Z&X))+V+M[ae]+1518500249)&4294967295;
+V=X;X=Y;Y=N(Z,30);Z=aa;aa=af}for(ae=20;ae<=39;ae++){af=(N(aa,5)+(Z^Y^X)+V+M[ae]+1859775393)&4294967295;V=X;X=Y;Y=N(Z,30);Z=aa;aa=af}for(ae=40;ae<=59;ae++){af=(N(aa,5)+((Z&Y)|(Z&X)|(Y&X))+V+M[ae]+2400959708)&4294967295;V=X;X=Y;Y=N(Z,30);Z=aa;aa=af}for(ae=60;ae<=79;ae++){af=(N(aa,5)+(Z^Y^X)+V+M[ae]+3395469782)&4294967295;V=X;X=Y;Y=N(Z,30);Z=aa;aa=af}U=(U+aa)&4294967295;S=(S+Z)&4294967295;R=(R+Y)&4294967295;P=(P+X)&4294967295;O=(O+V)&4294967295}af=ac(U)+ac(S)+ac(R)+ac(P)+ac(O);return af.toLowerCase()}function C(M,i,L){if(M==="translate.googleusercontent.com"){if(L===""){L=i}i=x(i,"u");M=b(i)}else{if(M==="cc.bingj.com"||M==="webcache.googleusercontent.com"||M.slice(0,5)==="74.6."){i=n.links[0].href;M=b(i)}}return[M,i,L]}function r(L){var i=L.length;if(L.charAt(--i)==="."){L=L.slice(0,i)}if(L.slice(0,2)==="*."){L=L.slice(1)}return L}function K(L){if(!h(L)){L=L.text||"";var i=n.getElementsByTagName("title");if(i&&p(i[0])){L=i[0].text}}return L}function s(O,S){var U="Piwik_Overlay";var R=n.referrer;
+var i=O;i=i.substring(0,i.length-9);i.substring(i.substring(0,7)==="http://"?7:8,i.length);R.substring(R.substring(0,7)==="http://"?7:8,R.length);if(R.substring(0,i.length)===i){var M=new RegExp("^"+i+"index\\.php\\?module=Overlay&action=startOverlaySession&idsite=([0-9]+)&period=([^&]+)&date=([^&]+)$");var N=R.match(M);if(N){var P=N[1];if(parseInt(P,10)!==S){return false}var Q=N[2];var L=N[3];window.name=U+"###"+Q+"###"+L}}var T=w.name.split("###");return T.length===3&&T[0]===U}function B(M,S){var T=window.name.split("###");var R=M.substring(0,M.length-9);var N=T[1];var i=T[2];var L=false;var O=function(){if(!L){L=true;Piwik_Overlay_Client.initialize(R,S,N,i)}};var Q=document.createElement("script");Q.type="text/javascript";Q.onreadystatechange=function(){if(this.readyState==="loaded"||this.readyState==="complete"){O()}};Q.onload=O;Q.src=R+"plugins/Overlay/client/client.js";var P=document.getElementsByTagName("head")[0];P.appendChild(Q)}function t(af,aE){var O=C(n.domain,w.location.href,q()),aX=r(O[0]),bb=O[1],aK=O[2],aI="GET",N=af||"",a1=aE||"",av,al=n.title,an="7z|aac|ar[cj]|as[fx]|avi|bin|csv|deb|dmg|doc|exe|flv|gif|gz|gzip|hqx|jar|jpe?g|js|mp(2|3|4|e?g)|mov(ie)?|ms[ip]|od[bfgpst]|og[gv]|pdf|phps|png|ppt|qtm?|ra[mr]?|rpm|sea|sit|tar|t?bz2?|tgz|torrent|txt|wav|wm[av]|wpd||xls|xml|z|zip",aG=[aX],R=[],az=[],ae=[],aF=500,S,ag,T,U,ap=["pk_campaign","piwik_campaign","utm_campaign","utm_source","utm_medium"],ak=["pk_kwd","piwik_kwd","utm_term"],a9="_pk_",X,ba,V=false,a4,ar,au,ac=63072000000,ad=1800000,aw=15768000000,aa=n.location.protocol==="https",Q=false,aA={},a5=200,aQ={},a2={},aN=false,aL=false,aJ,aB,Y,ao=I,aM,at;
+function aS(bk,bh,bg,bj,bf,bi){if(V){return}var be;if(bg){be=new Date();be.setTime(be.getTime()+bg)}n.cookie=bk+"="+g(bh)+(bg?";expires="+be.toGMTString():"")+";path="+(bj||"/")+(bf?";domain="+bf:"")+(bi?";secure":"")}function ab(bg){if(V){return 0}var be=new RegExp("(^|;)[ ]*"+bg+"=([^;]*)"),bf=be.exec(n.cookie);return bf?v(bf[2]):0}function a6(be){var bf;if(T){bf=new RegExp("#.*");return be.replace(bf,"")}return be}function aW(bg,be){var bh=f(be),bf;if(bh){return be}if(be.slice(0,1)==="/"){return f(bg)+"://"+b(bg)+be}bg=a6(bg);if((bf=bg.indexOf("?"))>=0){bg=bg.slice(0,bf)}if((bf=bg.lastIndexOf("/"))!==bg.length-1){bg=bg.slice(0,bf+1)}return bg+be}function aH(bh){var bf,be,bg;for(bf=0;bf<aG.length;bf++){be=r(aG[bf].toLowerCase());if(bh===be){return true}if(be.slice(0,1)==="."){if(bh===be.slice(1)){return true}bg=bh.length-be.length;if((bg>0)&&(bh.slice(bg)===be)){return true}}}return false}function bd(be){var bf=new Image(1,1);bf.onload=function(){};bf.src=N+(N.indexOf("?")<0?"?":"&")+be
+}function aT(be){try{var bg=w.XMLHttpRequest?new w.XMLHttpRequest():w.ActiveXObject?new ActiveXObject("Microsoft.XMLHTTP"):null;bg.open("POST",N,true);bg.onreadystatechange=function(){if(this.readyState===4&&this.status!==200){bd(be)}};bg.setRequestHeader("Content-Type","application/x-www-form-urlencoded; charset=UTF-8");bg.send(be)}catch(bf){bd(be)}}function aq(bg,bf){var be=new Date();if(!a4){if(aI==="POST"){aT(bg)}else{bd(bg)}e=be.getTime()+bf}}function aR(be){return a9+be+"."+a1+"."+aM}function P(){if(V){return"0"}if(!p(c.cookieEnabled)){var be=aR("testcookie");aS(be,"1");return ab(be)==="1"?"1":"0"}return c.cookieEnabled?"1":"0"}function aC(){aM=ao((X||aX)+(ba||"/")).slice(0,4)}function Z(){var bf=aR("cvar"),be=ab(bf);if(be.length){be=JSON2.parse(be);if(y(be)){return be}}return{}}function M(){if(Q===false){Q=Z()}}function a0(){var be=new Date();aJ=be.getTime()}function W(bi,bf,be,bh,bg,bj){aS(aR("id"),bi+"."+bf+"."+be+"."+bh+"."+bg+"."+bj,ac,ba,X,aa)}function L(){var bf=new Date(),be=Math.round(bf.getTime()/1000),bh=ab(aR("id")),bg;
+if(bh){bg=bh.split(".");bg.unshift("0")}else{if(!at){at=ao((c.userAgent||"")+(c.platform||"")+JSON2.stringify(a2)+be).slice(0,16)}bg=["1",at,be,0,be,"",""]}return bg}function i(){var be=ab(aR("ref"));if(be.length){try{be=JSON2.parse(be);if(y(be)){return be}}catch(bf){}}return["","",0,""]}function am(bg,bF,bG,bi){var bD,bf=new Date(),bo=Math.round(bf.getTime()/1000),bI,bE,bk,bw,bA,bn,by,bl,bC,bj=1024,bJ,br,bz=Q,bu=aR("id"),bp=aR("ses"),bq=aR("ref"),bK=aR("cvar"),bx=L(),bt=ab(bp),bB=i(),bH=av||bb,bm,be;if(V){V=false;aS(bu,"",-86400,ba,X);aS(bp,"",-86400,ba,X);aS(bK,"",-86400,ba,X);aS(bq,"",-86400,ba,X);V=true}if(a4){return""}bI=bx[0];bE=bx[1];bw=bx[2];bk=bx[3];bA=bx[4];bn=bx[5];if(!p(bx[6])){bx[6]=""}by=bx[6];if(!p(bi)){bi=""}var bs=document.characterSet||document.charset;if(!bs||bs.toLowerCase()==="utf-8"||bs.toLowerCase()==="iso-8859-1"||bs.toLowerCase()==="iso-8859-15"){bs=null}bm=bB[0];be=bB[1];bl=bB[2];bC=bB[3];if(!bt){bk++;bn=bA;if(!au||!bm.length){for(bD in ap){if(Object.prototype.hasOwnProperty.call(ap,bD)){bm=x(bH,ap[bD]);
+if(bm.length){break}}}for(bD in ak){if(Object.prototype.hasOwnProperty.call(ak,bD)){be=x(bH,ak[bD]);if(be.length){break}}}}bJ=b(aK);br=bC.length?b(bC):"";if(bJ.length&&!aH(bJ)&&(!au||!br.length||aH(br))){bC=aK}if(bC.length||bm.length){bl=bo;bB=[bm,be,bl,a6(bC.slice(0,bj))];aS(bq,JSON2.stringify(bB),aw,ba,X,aa)}}bg+="&idsite="+a1+"&rec=1&r="+String(Math.random()).slice(2,8)+"&h="+bf.getHours()+"&m="+bf.getMinutes()+"&s="+bf.getSeconds()+"&url="+g(a6(bH))+(aK.length?"&urlref="+g(a6(aK)):"")+"&_id="+bE+"&_idts="+bw+"&_idvc="+bk+"&_idn="+bI+(bm.length?"&_rcn="+g(bm):"")+(be.length?"&_rck="+g(be):"")+"&_refts="+bl+"&_viewts="+bn+(String(by).length?"&_ects="+by:"")+(String(bC).length?"&_ref="+g(a6(bC.slice(0,bj))):"")+(bs?"&cs="+g(bs):"");var bh=JSON2.stringify(aA);if(bh.length>2){bg+="&cvar="+g(bh)}for(bD in a2){if(Object.prototype.hasOwnProperty.call(a2,bD)){bg+="&"+bD+"="+a2[bD]}}if(bF){bg+="&data="+g(JSON2.stringify(bF))}else{if(U){bg+="&data="+g(JSON2.stringify(U))}}if(Q){var bv=JSON2.stringify(Q);
+if(bv.length>2){bg+="&_cvar="+g(bv)}for(bD in bz){if(Object.prototype.hasOwnProperty.call(bz,bD)){if(Q[bD][0]===""||Q[bD][1]===""){delete Q[bD]}}}aS(bK,JSON2.stringify(Q),ad,ba,X,aa)}W(bE,bw,bk,bo,bn,p(bi)&&String(bi).length?bi:by);aS(bp,"*",ad,ba,X,aa);bg+=E(bG);return bg}function aV(bh,bg,bl,bi,be,bo){var bj="idgoal=0",bk,bf=new Date(),bm=[],bn;if(String(bh).length){bj+="&ec_id="+g(bh);bk=Math.round(bf.getTime()/1000)}bj+="&revenue="+bg;if(String(bl).length){bj+="&ec_st="+bl}if(String(bi).length){bj+="&ec_tx="+bi}if(String(be).length){bj+="&ec_sh="+be}if(String(bo).length){bj+="&ec_dt="+bo}if(aQ){for(bn in aQ){if(Object.prototype.hasOwnProperty.call(aQ,bn)){if(!p(aQ[bn][1])){aQ[bn][1]=""}if(!p(aQ[bn][2])){aQ[bn][2]=""}if(!p(aQ[bn][3])||String(aQ[bn][3]).length===0){aQ[bn][3]=0}if(!p(aQ[bn][4])||String(aQ[bn][4]).length===0){aQ[bn][4]=1}bm.push(aQ[bn])}}bj+="&ec_items="+g(JSON2.stringify(bm))}bj=am(bj,U,"ecommerce",bk);aq(bj,aF)}function aU(be,bi,bh,bg,bf,bj){if(String(be).length&&p(bi)){aV(be,bi,bh,bg,bf,bj)
+}}function a8(be){if(p(be)){aV("",be,"","","","")}}function ay(bh,bi){var be=new Date(),bg=am("action_name="+g(K(bh||al)),bi,"log");aq(bg,aF);if(S&&ag&&!aL){aL=true;J(n,"click",a0);J(n,"mouseup",a0);J(n,"mousedown",a0);J(n,"mousemove",a0);J(n,"mousewheel",a0);J(w,"DOMMouseScroll",a0);J(w,"scroll",a0);J(n,"keypress",a0);J(n,"keydown",a0);J(n,"keyup",a0);J(w,"resize",a0);J(w,"focus",a0);J(w,"blur",a0);aJ=be.getTime();setTimeout(function bf(){var bj=new Date(),bk;if((aJ+ag)>bj.getTime()){if(S<bj.getTime()){bk=am("ping=1",bi,"ping");aq(bk,aF)}setTimeout(bf,ag)}},ag)}}function aj(be,bh,bf,bi){var bg=am("search="+g(be)+(bh?"&search_cat="+g(bh):"")+(p(bf)?"&search_count="+bf:""),bi,"sitesearch");aq(bg,aF)}function aD(be,bh,bg){var bf=am("idgoal="+be+(bh?"&revenue="+bh:""),bg,"goal");aq(bf,aF)}function aZ(bf,be,bh){var bg=am(be+"="+g(a6(bf)),bh,"link");aq(bg,aF)}function a3(bf,be){if(bf!==""){return bf+be.charAt(0).toUpperCase()+be.slice(1)}return be}function ai(bj){var bi,be,bh=["","webkit","ms","moz"],bg;
+if(!ar){for(be=0;be<bh.length;be++){bg=bh[be];if(Object.prototype.hasOwnProperty.call(n,a3(bg,"hidden"))){if(n[a3(bg,"visibilityState")]==="prerender"){bi=true}break}}}if(bi){J(n,bg+"visibilitychange",function bf(){n.removeEventListener(bg+"visibilitychange",bf,false);bj()});return}bj()}function ah(bg,bf){var bh,be="(^| )(piwik[_-]"+bf;if(bg){for(bh=0;bh<bg.length;bh++){be+="|"+bg[bh]}}be+=")( |$)";return new RegExp(be)}function aY(bh,be,bi){var bg=ah(az,"download"),bf=ah(ae,"link"),bj=new RegExp("\\.("+an+")([?&#]|$)","i");return bf.test(bh)?"link":(bg.test(bh)||bj.test(be)?"download":(bi?0:"link"))}function aP(bj){var bh,bf,be;while((bh=bj.parentNode)!==null&&p(bh)&&((bf=bj.tagName.toUpperCase())!=="A"&&bf!=="AREA")){bj=bh}if(p(bj.href)){var bk=bj.hostname||b(bj.href),bl=bk.toLowerCase(),bg=bj.href.replace(bk,bl),bi=new RegExp("^(javascript|vbscript|jscript|mocha|livescript|ecmascript|mailto):","i");if(!bi.test(bg)){be=aY(bj.className,bg,aH(bl));if(be){bg=d(bg);aZ(bg,be)}}}}function bc(be){var bf,bg;
+be=be||w.event;bf=be.which||be.button;bg=be.target||be.srcElement;if(be.type==="click"){if(bg){aP(bg)}}else{if(be.type==="mousedown"){if((bf===1||bf===2)&&bg){aB=bf;Y=bg}else{aB=Y=null}}else{if(be.type==="mouseup"){if(bf===aB&&bg===Y){aP(bg)}aB=Y=null}}}}function aO(bf,be){if(be){J(bf,"mouseup",bc,false);J(bf,"mousedown",bc,false)}else{J(bf,"click",bc,false)}}function ax(bf){if(!aN){aN=true;var bg,be=ah(R,"ignore"),bh=n.links;if(bh){for(bg=0;bg<bh.length;bg++){if(!be.test(bh[bg].className)){aO(bh[bg],bf)}}}}}function a7(){var bf,bg,bh={pdf:"application/pdf",qt:"video/quicktime",realp:"audio/x-pn-realaudio-plugin",wma:"application/x-mplayer2",dir:"application/x-director",fla:"application/x-shockwave-flash",java:"application/x-java-vm",gears:"application/x-googlegears",ag:"application/x-silverlight"},be=(new RegExp("Mac OS X.*Safari/")).test(c.userAgent)?w.devicePixelRatio||1:1;if(!((new RegExp("MSIE")).test(c.userAgent))){if(c.mimeTypes&&c.mimeTypes.length){for(bf in bh){if(Object.prototype.hasOwnProperty.call(bh,bf)){bg=c.mimeTypes[bh[bf]];
+a2[bf]=(bg&&bg.enabledPlugin)?"1":"0"}}}if(typeof navigator.javaEnabled!=="unknown"&&p(c.javaEnabled)&&c.javaEnabled()){a2.java="1"}if(l(w.GearsFactory)){a2.gears="1"}a2.cookie=P()}a2.res=z.width*be+"x"+z.height*be}a7();aC();return{getVisitorId:function(){return(L())[1]},getVisitorInfo:function(){return L()},getAttributionInfo:function(){return i()},getAttributionCampaignName:function(){return i()[0]},getAttributionCampaignKeyword:function(){return i()[1]},getAttributionReferrerTimestamp:function(){return i()[2]},getAttributionReferrerUrl:function(){return i()[3]},setTrackerUrl:function(be){N=be},setSiteId:function(be){a1=be},setCustomData:function(be,bf){if(y(be)){U=be}else{if(!U){U=[]}U[be]=bf}},getCustomData:function(){return U},setCustomVariable:function(bf,be,bi,bg){var bh;if(!p(bg)){bg="visit"}if(bf>0){be=p(be)&&!h(be)?String(be):be;bi=p(bi)&&!h(bi)?String(bi):bi;bh=[be.slice(0,a5),bi.slice(0,a5)];if(bg==="visit"||bg===2){M();Q[bf]=bh}else{if(bg==="page"||bg===3){aA[bf]=bh}}}},getCustomVariable:function(bf,bg){var be;
+if(!p(bg)){bg="visit"}if(bg==="page"||bg===3){be=aA[bf]}else{if(bg==="visit"||bg===2){M();be=Q[bf]}}if(!p(be)||(be&&be[0]==="")){return false}return be},deleteCustomVariable:function(be,bf){if(this.getCustomVariable(be,bf)){this.setCustomVariable(be,"","",bf)}},setLinkTrackingTimer:function(be){aF=be},setDownloadExtensions:function(be){an=be},addDownloadExtensions:function(be){an+="|"+be},setDomains:function(be){aG=h(be)?[be]:be;aG.push(aX)},setIgnoreClasses:function(be){R=h(be)?[be]:be},setRequestMethod:function(be){aI=be||"GET"},setReferrerUrl:function(be){aK=be},setCustomUrl:function(be){av=aW(bb,be)},setDocumentTitle:function(be){al=be},setDownloadClasses:function(be){az=h(be)?[be]:be},setLinkClasses:function(be){ae=h(be)?[be]:be},setCampaignNameKey:function(be){ap=h(be)?[be]:be},setCampaignKeywordKey:function(be){ak=h(be)?[be]:be},discardHashTag:function(be){T=be},setCookieNamePrefix:function(be){a9=be;Q=Z()},setCookieDomain:function(be){X=r(be);aC()},setCookiePath:function(be){ba=be;
+aC()},setVisitorCookieTimeout:function(be){ac=be*1000},setSessionCookieTimeout:function(be){ad=be*1000},setReferralCookieTimeout:function(be){aw=be*1000},setConversionAttributionFirstReferrer:function(be){au=be},disableCookies:function(){V=true;a2.cookie="0"},setDoNotTrack:function(bf){var be=c.doNotTrack||c.msDoNotTrack;a4=bf&&(be==="yes"||be==="1");if(a4){this.disableCookies()}},addListener:function(bf,be){aO(bf,be)},enableLinkTracking:function(be){if(k){ax(be)}else{u.push(function(){ax(be)})}},setHeartBeatTimer:function(bg,bf){var be=new Date();S=be.getTime()+bg*1000;ag=bf*1000},killFrame:function(){if(w.location!==w.top.location){w.top.location=w.location}},redirectFile:function(be){if(w.location.protocol==="file:"){w.location=be}},setCountPreRendered:function(be){ar=be},trackGoal:function(be,bg,bf){ai(function(){aD(be,bg,bf)})},trackLink:function(bf,be,bg){ai(function(){aZ(bf,be,bg)})},trackPageView:function(be,bf){if(s(N,a1)){ai(function(){B(N,a1)})}else{ai(function(){ay(be,bf)})}},trackSiteSearch:function(be,bg,bf){ai(function(){aj(be,bg,bf)
+})},setEcommerceView:function(bh,be,bg,bf){if(!p(bg)||!bg.length){bg=""}else{if(bg instanceof Array){bg=JSON2.stringify(bg)}}aA[5]=["_pkc",bg];if(p(bf)&&String(bf).length){aA[2]=["_pkp",bf]}if((!p(bh)||!bh.length)&&(!p(be)||!be.length)){return}if(p(bh)&&bh.length){aA[3]=["_pks",bh]}if(!p(be)||!be.length){be=""}aA[4]=["_pkn",be]},addEcommerceItem:function(bi,be,bg,bf,bh){if(bi.length){aQ[bi]=[bi,be,bg,bf,bh]}},trackEcommerceOrder:function(be,bi,bh,bg,bf,bj){aU(be,bi,bh,bg,bf,bj)},trackEcommerceCartUpdate:function(be){a8(be)}}}function o(){return{push:G}}J(w,"beforeunload",H,false);j();Date.prototype.getTimeAlias=Date.prototype.getTime;A=new t();for(D=0;D<_paq.length;D++){G(_paq[D])}_paq=new o();return{addPlugin:function(i,L){a[i]=L},getTracker:function(i,L){return new t(i,L)},getAsyncTracker:function(){return A}}}()),piwik_track,piwik_log=function(b,f,d,g){function a(h){try{return eval("piwik_"+h)}catch(i){}return}var c,e=Piwik.getTracker(d,f);e.setDocumentTitle(b);e.setCustomData(g);
+c=a("tracker_pause");if(c){e.setLinkTrackingTimer(c)}c=a("download_extensions");if(c){e.setDownloadExtensions(c)}c=a("hosts_alias");if(c){e.setDomains(c)}c=a("ignore_classes");if(c){e.setIgnoreClasses(c)}e.trackPageView();if(a("install_tracker")){piwik_track=function(i,k,j,h){e.setSiteId(k);e.setTrackerUrl(j);e.trackLink(i,h)};e.enableLinkTracking()}};
diff --git a/plugins/Actions/Controller.php b/plugins/Actions/Controller.php
index 44ee4416f7..14af64b087 100644
--- a/plugins/Actions/Controller.php
+++ b/plugins/Actions/Controller.php
@@ -24,8 +24,8 @@ class Piwik_Actions_Controller extends Piwik_Controller
$view = Piwik_ViewDataTable::factory();
$view->init($this->pluginName, $currentAction, $apiAction, $controllerActionSubtable);
$view->setColumnTranslation('label', Piwik_Translate('Actions_ColumnPageURL'));
- if (Piwik_Config::getInstance()->General['insight_launch_from_pages_report']) {
- $view->openLinksInInsight();
+ if (Piwik_Config::getInstance()->General['overlay_launch_from_pages_report']) {
+ $view->openLinksInOverlay();
}
return $view;
}
diff --git a/plugins/CoreHome/templates/datatable.js b/plugins/CoreHome/templates/datatable.js
index bcf0ad5fa0..1426dbea83 100644
--- a/plugins/CoreHome/templates/datatable.js
+++ b/plugins/CoreHome/templates/datatable.js
@@ -1339,13 +1339,13 @@ dataTable.prototype =
}
});
- if (typeof self.param.open_links_in_insight != 'undefined' && self.param.open_links_in_insight)
+ if (typeof self.param.open_links_in_overlay != 'undefined' && self.param.open_links_in_overlay)
{
var link = td.find('a');
link.click(function()
{
var rowUrl = $(this).attr('href');
- var newUrl = 'module=Insight&action=index&insightUrl=' + encodeURIComponent(rowUrl).replace(/%/g, '$');
+ var newUrl = 'module=Overlay&action=index&overlayUrl=' + encodeURIComponent(rowUrl).replace(/%/g, '$');
$('ul.nav').trigger('piwikSwitchPage');
broadcast.propagateAjax(newUrl);
diff --git a/plugins/Insight/API.php b/plugins/Overlay/API.php
index 94ca119fe2..94ca119fe2 100644
--- a/plugins/Insight/API.php
+++ b/plugins/Overlay/API.php
diff --git a/plugins/Insight/Controller.php b/plugins/Overlay/Controller.php
index a2258f611b..a2258f611b 100644
--- a/plugins/Insight/Controller.php
+++ b/plugins/Overlay/Controller.php
diff --git a/plugins/Insight/Insight.php b/plugins/Overlay/Overlay.php
index 63dd021c93..446cb47a6e 100644
--- a/plugins/Insight/Insight.php
+++ b/plugins/Overlay/Overlay.php
@@ -40,7 +40,7 @@ class Piwik_Insight extends Piwik_Plugin
public function getJsFiles($notification)
{
$jsFiles = &$notification->getNotificationObject();
- $jsFiles[] = "plugins/Insight/templates/insight.js";
+ $jsFiles[] = "plugins/Insight/templates/index.js";
}
public function addMenu()
diff --git a/plugins/Insight/client/insight.css b/plugins/Overlay/client/client.css
index 9484de5458..9484de5458 100644
--- a/plugins/Insight/client/insight.css
+++ b/plugins/Overlay/client/client.css
diff --git a/plugins/Insight/client/client.js b/plugins/Overlay/client/client.js
index ff3e0712ba..ff3e0712ba 100644
--- a/plugins/Insight/client/client.js
+++ b/plugins/Overlay/client/client.js
diff --git a/plugins/Insight/client/close.png b/plugins/Overlay/client/close.png
index 1514d51a3c..1514d51a3c 100644
--- a/plugins/Insight/client/close.png
+++ b/plugins/Overlay/client/close.png
Binary files differ
diff --git a/plugins/Insight/client/followingpages.js b/plugins/Overlay/client/followingpages.js
index 46dfd151b7..46dfd151b7 100644
--- a/plugins/Insight/client/followingpages.js
+++ b/plugins/Overlay/client/followingpages.js
diff --git a/plugins/Insight/client/linktags.eps b/plugins/Overlay/client/linktags.eps
index b9279b8a95..b9279b8a95 100644
--- a/plugins/Insight/client/linktags.eps
+++ b/plugins/Overlay/client/linktags.eps
diff --git a/plugins/Insight/client/linktags.png b/plugins/Overlay/client/linktags.png
index ba118008dc..ba118008dc 100644
--- a/plugins/Insight/client/linktags.png
+++ b/plugins/Overlay/client/linktags.png
Binary files differ
diff --git a/plugins/Insight/client/linktags.psd b/plugins/Overlay/client/linktags.psd
index 31b770b81b..31b770b81b 100644
--- a/plugins/Insight/client/linktags.psd
+++ b/plugins/Overlay/client/linktags.psd
Binary files differ
diff --git a/plugins/Insight/client/linktags_lessshadow.png b/plugins/Overlay/client/linktags_lessshadow.png
index e57f8ad617..e57f8ad617 100644
--- a/plugins/Insight/client/linktags_lessshadow.png
+++ b/plugins/Overlay/client/linktags_lessshadow.png
Binary files differ
diff --git a/plugins/Insight/client/linktags_noshadow.png b/plugins/Overlay/client/linktags_noshadow.png
index 3290b1a177..3290b1a177 100644
--- a/plugins/Insight/client/linktags_noshadow.png
+++ b/plugins/Overlay/client/linktags_noshadow.png
Binary files differ
diff --git a/plugins/Insight/client/loading.gif b/plugins/Overlay/client/loading.gif
index 4df2f1fde6..4df2f1fde6 100644
--- a/plugins/Insight/client/loading.gif
+++ b/plugins/Overlay/client/loading.gif
Binary files differ
diff --git a/plugins/Insight/client/translations.js b/plugins/Overlay/client/translations.js
index 024deb1864..024deb1864 100644
--- a/plugins/Insight/client/translations.js
+++ b/plugins/Overlay/client/translations.js
diff --git a/plugins/Insight/client/urlnormalizer.js b/plugins/Overlay/client/urlnormalizer.js
index fcdf386c63..fcdf386c63 100644
--- a/plugins/Insight/client/urlnormalizer.js
+++ b/plugins/Overlay/client/urlnormalizer.js
diff --git a/plugins/Insight/templates/index.css b/plugins/Overlay/templates/index.css
index eaa114f84a..eaa114f84a 100644
--- a/plugins/Insight/templates/index.css
+++ b/plugins/Overlay/templates/index.css
diff --git a/plugins/Insight/templates/insight.js b/plugins/Overlay/templates/index.js
index f3bd1d07b9..f3bd1d07b9 100644
--- a/plugins/Insight/templates/insight.js
+++ b/plugins/Overlay/templates/index.js
diff --git a/plugins/Insight/templates/index.tpl b/plugins/Overlay/templates/index.tpl
index deadb31c2b..deadb31c2b 100644
--- a/plugins/Insight/templates/index.tpl
+++ b/plugins/Overlay/templates/index.tpl
diff --git a/plugins/Insight/templates/index_noframe.tpl b/plugins/Overlay/templates/index_noframe.tpl
index 5d1d77b6b6..5d1d77b6b6 100644
--- a/plugins/Insight/templates/index_noframe.tpl
+++ b/plugins/Overlay/templates/index_noframe.tpl
diff --git a/plugins/Insight/templates/info.png b/plugins/Overlay/templates/info.png
index 12cd1aef90..12cd1aef90 100644
--- a/plugins/Insight/templates/info.png
+++ b/plugins/Overlay/templates/info.png
Binary files differ
diff --git a/plugins/Insight/templates/notify_parent_iframe.tpl b/plugins/Overlay/templates/notify_parent_iframe.tpl
index 04e3bd2ee0..04e3bd2ee0 100644
--- a/plugins/Insight/templates/notify_parent_iframe.tpl
+++ b/plugins/Overlay/templates/notify_parent_iframe.tpl
diff --git a/plugins/Insight/templates/sidebar.tpl b/plugins/Overlay/templates/sidebar.tpl
index b2777d73d3..b2777d73d3 100644
--- a/plugins/Insight/templates/sidebar.tpl
+++ b/plugins/Overlay/templates/sidebar.tpl
diff --git a/tests/PHPUnit/IntegrationTestCase.php b/tests/PHPUnit/IntegrationTestCase.php
index add4714be0..37ea41405a 100755
--- a/tests/PHPUnit/IntegrationTestCase.php
+++ b/tests/PHPUnit/IntegrationTestCase.php
@@ -161,7 +161,7 @@ abstract class IntegrationTestCase extends PHPUnit_Framework_TestCase
'UsersManager',
'SitesManager',
'ExampleUI',
- 'Insight',
+ 'Overlay',
'Live',
'SEO',
'ExampleAPI',
diff --git a/config/global.ini.php b/config/global.ini.php
index 48e50aaa27..16abb38e2b 100644
--- a/config/global.ini.php
+++ b/config/global.ini.php
@@ -311,16 +311,16 @@ api_service_url = http://api.piwik.org
; eg. $period=range&date=previous10 becomes $period=day&date=previous10. Use this setting to override the $period value.
graphs_default_period_to_plot_when_period_range = day
; The Insight plugin shows the Top X following pages, Top X downloads and Top X outlinks which followed
; a view of the current page. The value X can be set here.
-insight_limit = 300
+overlay_following_pages_limit = 300
-; With this option, you can disable the framed mode of the Insight plugin. If set to 1, the Insight session
+; With this option, you can disable the framed mode of the Overlay plugin. If set to 1, the Page Overlay session
; will be started in a new tab instead of the iframe.
-insight_disable_framed_mode = 0
+overlay_disable_framed_mode = 0
-; If this option is set, the links in the pages reports will not be opened in a new tab but will launch Insight instead.
-insight_launch_from_pages_report = 0
+; If this option is set, the links in the pages reports will not be opened in a new tab but will launch Page Overlay instead.
+overlay_launch_from_pages_report = 0
[Tracker]
; Piwik uses first party cookies by default. If set to 1,
@@ -311,16 +311,16 @@ api_service_url = http://api.piwik.org
; eg. $period=range&date=previous10 becomes $period=day&date=previous10. Use this setting to override the $period value.
graphs_default_period_to_plot_when_period_range = day
-; The Insight plugin shows the Top X following pages, Top X downloads and Top X outlinks which followed
+; The Overlay plugin shows the Top X following pages, Top X downloads and Top X outlinks which followed
; a view of the current page. The value X can be set here.
diff --git a/core/ViewDataTable/HtmlTable.php b/core/ViewDataTable/HtmlTable.php
index 97210533db..f23f356ef7 100644
--- a/core/ViewDataTable/HtmlTable.php
+++ b/core/ViewDataTable/HtmlTable.php
@@ -235,11 +235,11 @@ class Piwik_ViewDataTable_HtmlTable extends Piwik_ViewDataTable
}
/**
* Use this method to open links in Insight instead of a new tab
*/
- public function openLinksInInsight()
+ public function openLinksInOverlay()
{
- $this->variablesDefault['open_links_in_insight'] = true;
+ $this->variablesDefault['open_links_in_overlay'] = true;
}
}
@@ -235,11 +235,11 @@ class Piwik_ViewDataTable_HtmlTable extends Piwik_ViewDataTable
}
/**
- * Use this method to open links in Insight instead of a new tab
+ * Use this method to open links in Overlay instead of a new tab
*/
diff --git a/js/piwik.js b/js/piwik.js
index b430a2425d..7a978ce925 100644
--- a/js/piwik.js
+++ b/js/piwik.js
@@ -899,14 +899,14 @@ var
}
/************************************************************
- * Page Insight
+ * Page Overlay
************************************************************/
/*
* check whether this is an insight session
*/
- function isInsightSession(configTrackerUrl, configTrackerSiteId) {
- var windowName = 'Piwik_Insight';
+ function isOverlaySession(configTrackerUrl, configTrackerSiteId) {
+ var windowName = 'Piwik_Overlay';
var referrer = documentAlias.referrer;
var testReferrer = configTrackerUrl;
@@ -923,7 +923,7 @@ var
// build referrer regex to extract parameters
var referrerRegExp = new RegExp('^' + testReferrer
- + 'index\\.php\\?module=Insight&action=startInsightSession'
+ + 'index\\.php\\?module=Overlay&action=startOverlaySession'
+ '&idsite=([0-9]+)&period=([^&]+)&date=([^&]+)$');
var match = referrer.match(referrerRegExp);
@@ -933,7 +933,7 @@ var
if (parseInt(idsite, 10) !== configTrackerSiteId) {
return false;
}
// store insight session info in window name
var period = match[2];
var date = match[3];
window.name = windowName + '###' + period + '###' + date;
@@ -946,9 +946,9 @@ var
}
/*
* inject the script needed for insight
*/
- function injectInsightScripts(configTrackerUrl, configTrackerSiteId) {
+ function injectOverlayScripts(configTrackerUrl, configTrackerSiteId) {
var windowNameParts = window.name.split('###');
var root = configTrackerUrl.substring(0, configTrackerUrl.length - 9); // remove piwik.php
var period = windowNameParts[1];
@@ -958,7 +958,7 @@ var
var onLoad = function () {
if (!loaded) {
loaded = true;
- Piwik_Insight_Client.initialize(root, configTrackerSiteId, period, date);
+ Piwik_Overlay_Client.initialize(root, configTrackerSiteId, period, date);
}
};
@@ -971,12 +971,12 @@ var
}
};
script.onload = onLoad;
- script.src = root + 'plugins/Insight/client/client.js';
+ script.src = root + 'plugins/Overlay/client/client.js';
var head = document.getElementsByTagName('head')[0];
head.appendChild(script);
}
/************************************************************
- * End Piwik Insight
+ * End Page Overlay
************************************************************/
/*
@@ -2667,9 +2667,9 @@ var
* @param mixed customData
*/
trackPageView: function (customTitle, customData) {
- if (isInsightSession(configTrackerUrl, configTrackerSiteId)) {
+ if (isOverlaySession(configTrackerUrl, configTrackerSiteId)) {
trackCallback(function () {
- injectInsightScripts(configTrackerUrl, configTrackerSiteId);
+ injectOverlayScripts(configTrackerUrl, configTrackerSiteId);
});
} else {
trackCallback(function () {
@@ -899,14 +899,14 @@ var
************************************************************/
/*
- * check whether this is an insight session
+ * check whether this is a page overlay session
*/
@@ -933,7 +933,7 @@ var
return false;
}
- // store insight session info in window name
+ // store overlay session info in window name
var period = match[2];
var date = match[3];
@@ -946,9 +946,9 @@ var
}
/*
- * inject the script needed for insight
+ * inject the script needed for page overlay
*/
diff --git a/plugins/CoreHome/templates/broadcast.js b/plugins/CoreHome/templates/broadcast.js
index eddd3e2da6..4d7c695d42 100644
--- a/plugins/CoreHome/templates/broadcast.js
+++ b/plugins/CoreHome/templates/broadcast.js
@@ -204,10 +204,10 @@ var broadcast = {
{
currentHashStr = broadcast.updateParamValue('idDashboard=', currentHashStr);
}
- // unset insightUrl if use doesn't display a page overlay
- if( module != 'Insight')
+ // unset overlayUrl if use doesn't display a page overlay
+ if( module != 'Overlay')
{
- currentHashStr = broadcast.updateParamValue('insightUrl=', currentHashStr);
+ currentHashStr = broadcast.updateParamValue('overlayUrl=', currentHashStr);
}
if (disableHistory)